==> certmanager-model-v1alpha2-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ChallengeStatusFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ChallengeStatusFluent<A extends ChallengeStatusFluent<A>> extends BaseFluent<A>{
  public ChallengeStatusFluent() {
  }
  public ChallengeStatusFluent(ChallengeStatus instance) {
    instance = (instance != null ? instance : new ChallengeStatus());

    if (instance != null) {
      this.withPresented(instance.getPresented());
      this.withProcessing(instance.getProcessing());
      this.withReason(instance.getReason());
      this.withState(instance.getState());
      this.withPresented(instance.getPresented());
      this.withProcessing(instance.getProcessing());
      this.withReason(instance.getReason());
      this.withState(instance.getState());
    }
  }
  private Boolean presented;
  private Boolean processing;
  private String reason;
  private String state;
  public Boolean getPresented() {
    return this.presented;
  }
  public A withPresented(Boolean presented) {
    this.presented=presented; return (A) this;
  }
  public boolean hasPresented() {
    return this.presented != null;
  }
  public Boolean getProcessing() {
    return this.processing;
  }
  public A withProcessing(Boolean processing) {
    this.processing=processing; return (A) this;
  }
  public boolean hasProcessing() {
    return this.processing != null;
  }
  public String getReason() {
    return this.reason;
  }
  public A withReason(String reason) {
    this.reason=reason; return (A) this;
  }
  public boolean hasReason() {
    return this.reason != null;
  }
  public String getState() {
    return this.state;
  }
  public A withState(String state) {
    this.state=state; return (A) this;
  }
  public boolean hasState() {
    return this.state != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ChallengeStatusFluent that = (ChallengeStatusFluent) o;
    if (!java.util.Objects.equals(presented, that.presented)) return false;

    if (!java.util.Objects.equals(processing, that.processing)) return false;

    if (!java.util.Objects.equals(reason, that.reason)) return false;

    if (!java.util.Objects.equals(state, that.state)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(presented,  processing,  reason,  state,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (presented != null) { sb.append("presented:"); sb.append(presented + ","); }
    if (processing != null) { sb.append("processing:"); sb.append(processing + ","); }
    if (reason != null) { sb.append("reason:"); sb.append(reason + ","); }
    if (state != null) { sb.append("state:"); sb.append(state); }
    sb.append("}");
    return sb.toString();
  }
  public A withPresented() {
    return withPresented(true);
  }
  public A withProcessing() {
    return withProcessing(true);
  }
  
}

==> certmanager-model-v1alpha2-6.9.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ChallengeStatusFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ChallengeStatusFluent<A extends ChallengeStatusFluent<A>> extends BaseFluent<A>{
  public ChallengeStatusFluent() {
  }
  
  public ChallengeStatusFluent(ChallengeStatus instance) {
    this.copyInstance(instance);
  }
  private Boolean presented;
  private Boolean processing;
  private String reason;
  private String state;
  
  protected void copyInstance(ChallengeStatus instance) {
    instance = (instance != null ? instance : new ChallengeStatus());
  
    if (instance != null) {
        this.withPresented(instance.getPresented());
        this.withProcessing(instance.getProcessing());
        this.withReason(instance.getReason());
        this.withState(instance.getState());
        this.withPresented(instance.getPresented());
        this.withProcessing(instance.getProcessing());
        this.withReason(instance.getReason());
        this.withState(instance.getState());
      }
  }
  
  public Boolean getPresented() {
    return this.presented;
  }
  
  public A withPresented(Boolean presented) {
    this.presented=presented; return (A) this;
  }
  
  public boolean hasPresented() {
    return this.presented != null;
  }
  
  public Boolean getProcessing() {
    return this.processing;
  }
  
  public A withProcessing(Boolean processing) {
    this.processing=processing; return (A) this;
  }
  
  public boolean hasProcessing() {
    return this.processing != null;
  }
  
  public String getReason() {
    return this.reason;
  }
  
  public A withReason(String reason) {
    this.reason=reason; return (A) this;
  }
  
  public boolean hasReason() {
    return this.reason != null;
  }
  
  public String getState() {
    return this.state;
  }
  
  public A withState(String state) {
    this.state=state; return (A) this;
  }
  
  public boolean hasState() {
    return this.state != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ChallengeStatusFluent that = (ChallengeStatusFluent) o;
    if (!java.util.Objects.equals(presented, that.presented)) return false;
  
    if (!java.util.Objects.equals(processing, that.processing)) return false;
  
    if (!java.util.Objects.equals(reason, that.reason)) return false;
  
    if (!java.util.Objects.equals(state, that.state)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(presented,  processing,  reason,  state,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (presented != null) { sb.append("presented:"); sb.append(presented + ","); }
    if (processing != null) { sb.append("processing:"); sb.append(processing + ","); }
    if (reason != null) { sb.append("reason:"); sb.append(reason + ","); }
    if (state != null) { sb.append("state:"); sb.append(state); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withPresented() {
    return withPresented(true);
  }
  
  public A withProcessing() {
    return withProcessing(true);
  }
  

}
